==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/StatelessComponent.js <==
import './node_modules/core-js/modules/es.date.to-string.js';
import './node_modules/core-js/modules/es.object.to-string.js';
import './node_modules/core-js/modules/es.reflect.construct.js';
import './node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Vue, Prop, Component } from 'vue-property-decorator';
import { css } from '@uifabric-vue/utilities';
import { getTheme } from '@uifabric/styling';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

var StatelessComponent = function (_Vue) {
  _inherits(StatelessComponent, _Vue);

  var _super = _createSuper(StatelessComponent);

  function StatelessComponent() {
    _classCallCheck(this, StatelessComponent);

    return _super.apply(this, arguments);
  }

  _createClass(StatelessComponent, [{
    key: "css",
    value: function css$1() {
      return css.apply(void 0, arguments);
    }
  }]);

  return StatelessComponent;
}(Vue);

__decorate([Prop({
  type: [String, Array],
  "default": ''
}), __metadata("design:type", String)], StatelessComponent.prototype, "className", void 0);

__decorate([Prop({
  type: [Object, Function],
  "default": function _default() {}
}), __metadata("design:type", Object)], StatelessComponent.prototype, "styles", void 0);

__decorate([Prop({
  type: Object,
  "default": function _default() {
    return getTheme();
  }
}), __metadata("design:type", Object)], StatelessComponent.prototype, "theme", void 0);

StatelessComponent = __decorate([Component({
  functional: true,
  provide: {}
})], StatelessComponent);
var StatelessComponent$1 = StatelessComponent;

export default StatelessComponent$1;

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/StatelessComponent.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Vue, Prop, Component } from 'vue-property-decorator';
import { css } from '@uifabric-vue/utilities';
import { getTheme } from '@uifabric/styling';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

var StatelessComponent = function (_Vue) {
  _inherits(StatelessComponent, _Vue);

  var _super = _createSuper(StatelessComponent);

  function StatelessComponent() {
    _classCallCheck(this, StatelessComponent);

    return _super.apply(this, arguments);
  }

  _createClass(StatelessComponent, [{
    key: "css",
    value: function css$1() {
      return css.apply(void 0, arguments);
    }
  }]);

  return StatelessComponent;
}(Vue);

__decorate([Prop({
  type: [String, Array],
  default: ''
}), __metadata("design:type", String)], StatelessComponent.prototype, "className", void 0);

__decorate([Prop({
  type: [Object, Function],
  default: function _default() {}
}), __metadata("design:type", Object)], StatelessComponent.prototype, "styles", void 0);

__decorate([Prop({
  type: Object,
  default: function _default() {
    return getTheme();
  }
}), __metadata("design:type", Object)], StatelessComponent.prototype, "theme", void 0);

StatelessComponent = __decorate([Component({
  functional: true,
  provide: {}
})], StatelessComponent);
var StatelessComponent$1 = StatelessComponent;

export default StatelessComponent$1;
